class Encoder(Module):
  __parameters__ = ["pos_embed", ]
  __buffers__ = []
  pos_embed : Tensor
  training : bool
  _is_full_backward_hook : Optional[bool]
  num_classes : int
  global_pool : str
  num_features : int
  embed_dim : int
  num_prefix_tokens : int
  no_embed_class : bool
  grad_checkpointing : bool
  cls_token : NoneType
  patch_embed : __torch__.timm.models.layers.patch_embed.PatchEmbed
  pos_drop : __torch__.torch.nn.modules.dropout.Dropout
  blocks : __torch__.torch.nn.modules.container.Sequential
  norm : __torch__.torch.nn.modules.normalization.LayerNorm
  fc_norm : __torch__.torch.nn.modules.linear.Identity
  head : __torch__.torch.nn.modules.linear.Identity
  def forward(self: __torch__.strhub.models.parseq.modules.Encoder,
    x: Tensor) -> Tensor:
    return (self).forward_features(x, )
  def forward_features(self: __torch__.strhub.models.parseq.modules.Encoder,
    x: Tensor) -> Tensor:
    patch_embed = self.patch_embed
    x0 = (patch_embed).forward(x, )
    x1 = (self)._pos_embed(x0, )
    blocks = self.blocks
    x2 = (blocks).forward(x1, )
    norm = self.norm
    return (norm).forward(x2, )
  def _pos_embed(self: __torch__.strhub.models.parseq.modules.Encoder,
    x: Tensor) -> Tensor:
    no_embed_class = self.no_embed_class
    if no_embed_class:
      pos_embed = self.pos_embed
      x3 = torch.add(x, pos_embed)
    else:
      pos_embed0 = self.pos_embed
      x3 = torch.add(x, pos_embed0)
    pos_drop = self.pos_drop
    return (pos_drop).forward(x3, )
class Decoder(Module):
  __parameters__ = []
  __buffers__ = []
  training : bool
  _is_full_backward_hook : Optional[bool]
  num_layers : int
  layers : __torch__.torch.nn.modules.container.ModuleList
  norm : __torch__.torch.nn.modules.normalization.___torch_mangle_4.LayerNorm
  def forward(self: __torch__.strhub.models.parseq.modules.Decoder,
    query: Tensor,
    content: Tensor,
    memory: Tensor,
    query_mask: Optional[Tensor]=None,
    content_mask: Optional[Tensor]=None,
    content_key_padding_mask: Optional[Tensor]=None) -> Tensor:
    layers = self.layers
    _0 = getattr(layers, "0")
    layers0 = self.layers
    last = torch.eq(0, torch.sub((layers0).__len__(), 1))
    _1 = (_0).forward(query, content, memory, query_mask, content_mask, content_key_padding_mask, torch.__not__(last), )
    query0, content0, = _1
    norm = self.norm
    return (norm).forward(query0, )
class DecoderLayer(Module):
  __parameters__ = []
  __buffers__ = []
  training : bool
  _is_full_backward_hook : Optional[bool]
  self_attn : __torch__.torch.nn.modules.activation.MultiheadAttention
  cross_attn : __torch__.torch.nn.modules.activation.MultiheadAttention
  linear1 : __torch__.torch.nn.modules.linear.___torch_mangle_1.Linear
  dropout : __torch__.torch.nn.modules.dropout.___torch_mangle_3.Dropout
  linear2 : __torch__.torch.nn.modules.linear.___torch_mangle_2.Linear
  norm1 : __torch__.torch.nn.modules.normalization.___torch_mangle_4.LayerNorm
  norm2 : __torch__.torch.nn.modules.normalization.___torch_mangle_4.LayerNorm
  norm_q : __torch__.torch.nn.modules.normalization.___torch_mangle_4.LayerNorm
  norm_c : __torch__.torch.nn.modules.normalization.___torch_mangle_4.LayerNorm
  dropout1 : __torch__.torch.nn.modules.dropout.___torch_mangle_3.Dropout
  dropout2 : __torch__.torch.nn.modules.dropout.___torch_mangle_3.Dropout
  dropout3 : __torch__.torch.nn.modules.dropout.___torch_mangle_3.Dropout
  def forward(self: __torch__.strhub.models.parseq.modules.DecoderLayer,
    query: Tensor,
    content: Tensor,
    memory: Tensor,
    query_mask: Optional[Tensor]=None,
    content_mask: Optional[Tensor]=None,
    content_key_padding_mask: Optional[Tensor]=None,
    update_content: bool=True) -> Tuple[Tensor, Tensor]:
    norm_q = self.norm_q
    query_norm = (norm_q).forward(query, )
    norm_c = self.norm_c
    content_norm = (norm_c).forward(content, )
    _1 = (self).forward_stream(query, query_norm, content_norm, memory, query_mask, content_key_padding_mask, )
    query1 = (_1)[0]
    if update_content:
      _2 = (self).forward_stream(content, content_norm, content_norm, memory, content_mask, content_key_padding_mask, )
      content1 = (_2)[0]
    else:
      content1 = content
    return (query1, content1)
  def forward_stream(self: __torch__.strhub.models.parseq.modules.DecoderLayer,
    tgt: Tensor,
    tgt_norm: Tensor,
    tgt_kv: Tensor,
    memory: Tensor,
    tgt_mask: Optional[Tensor],
    tgt_key_padding_mask: Optional[Tensor]) -> Tuple[Tensor, Optional[Tensor], Optional[Tensor]]:
    self_attn = self.self_attn
    _3 = (self_attn).forward(tgt_norm, tgt_kv, tgt_kv, tgt_key_padding_mask, True, tgt_mask, )
    tgt2, sa_weights, = _3
    dropout1 = self.dropout1
    tgt0 = torch.add(tgt, (dropout1).forward(tgt2, ))
    cross_attn = self.cross_attn
    norm1 = self.norm1
    _4 = (cross_attn).forward((norm1).forward(tgt0, ), memory, memory, None, True, None, )
    tgt20, ca_weights, = _4
    dropout2 = self.dropout2
    tgt1 = torch.add(tgt0, (dropout2).forward(tgt20, ))
    linear2 = self.linear2
    dropout = self.dropout
    linear1 = self.linear1
    norm2 = self.norm2
    _5 = (linear1).forward((norm2).forward(tgt1, ), )
    _6 = __torch__.torch.nn.functional.gelu(_5, )
    tgt21 = (linear2).forward((dropout).forward(_6, ), )
    dropout3 = self.dropout3
    tgt3 = torch.add(tgt1, (dropout3).forward(tgt21, ))
    return (tgt3, sa_weights, ca_weights)
class TokenEmbedding(Module):
  __parameters__ = []
  __buffers__ = []
  training : bool
  _is_full_backward_hook : Optional[bool]
  embed_dim : int
  embedding : __torch__.torch.nn.modules.sparse.Embedding
  def forward(self: __torch__.strhub.models.parseq.modules.TokenEmbedding,
    tokens: Tensor) -> Tensor:
    embed_dim = self.embed_dim
    _7 = torch.sqrt(embed_dim)
    embedding = self.embedding
    _8 = torch.mul((embedding).forward(tokens, ), _7)
    return _8
